@@ -10,9 +10,9 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MARIADB_CLIENT_VERSION_STR	"11.4.5"
+#define MARIADB_CLIENT_VERSION_STR	"11.4.7"
 #define MARIADB_BASE_VERSION		"mariadb-11.4"
-#define MARIADB_VERSION_ID		110405
+#define MARIADB_VERSION_ID		110407
 #define MARIADB_PORT	        	3306
 #define MARIADB_UNIX_ADDR               "/tmp/mysql.sock"
 #ifndef MYSQL_UNIX_ADDR
@@ -23,13 +23,13 @@
 #endif
 
 #define MYSQL_CONFIG_NAME               "my"
-#define MYSQL_VERSION_ID                110405
-#define MYSQL_SERVER_VERSION            "11.4.5-MariaDB"
+#define MYSQL_VERSION_ID                110407
+#define MYSQL_SERVER_VERSION            "11.4.7-MariaDB"
 
-#define MARIADB_PACKAGE_VERSION "3.4.4"
-#define MARIADB_PACKAGE_VERSION_ID 30404
+#define MARIADB_PACKAGE_VERSION "3.4.6"
+#define MARIADB_PACKAGE_VERSION_ID 30406
 #define MARIADB_SYSTEM_TYPE "NetBSD"
-#define MARIADB_MACHINE_TYPE "earmv6hf"
+#define MARIADB_MACHINE_TYPE "m68k"
 #define MARIADB_PLUGINDIR "/usr/pkg/lib/mysql/plugin"
 
 /* mysqld compile time options */
